==> qtjsbackend-opensource-src_5.0.2.orig.tar.xz: qtjsbackend-opensource-src-5.0.2/src/3rdparty/v8/test/mjsunit/regress/regress-117409.js <==
// Copyright 2012 the V8 project authors. All rights reserved.
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Google Inc. nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Flags: --expose-gc

function KeyedStoreIC(a) { a[0] = Math.E; }

// Create literal with a fast double elements backing store
var literal = [1.2];

// Specialize the IC for fast double elements
KeyedStoreIC(literal);
KeyedStoreIC(literal);

// Trruncate array to 0 elements, at which point backing store will be replaced
// with empty fixed array.
literal.length = 0;

// ArrayPush built-in will replace empty fixed array backing store with 19
// elements fixed array backing store.  This leads to a mismatch between the map
// and the backing store.  Debug mode will crash here in set_elements accessor.
literal.push(Math.E, Math.E);

// Corrupt the backing store!
KeyedStoreIC(literal);

// Release mode will crash here when trying to visit parts of E as pointers.
gc();

==> qtjsbackend-opensource-src_5.1.1.orig.tar.xz: qtjsbackend-opensource-src-5.1.1/src/3rdparty/v8/test/mjsunit/regress/regress-117409.js <==
// Copyright 2012 the V8 project authors. All rights reserved.
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Google Inc. nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Flags: --expose-gc

function KeyedStoreIC(a) { a[0] = Math.E; }

// Create literal with a fast double elements backing store
var literal = [1.2];

// Specialize the IC for fast double elements
KeyedStoreIC(literal);
KeyedStoreIC(literal);

// Truncate array to 0 elements, at which point backing store will be replaced
// with empty fixed array.
literal.length = 0;

// ArrayPush built-in will replace empty fixed array backing store with 19
// elements fixed array backing store.  This leads to a mismatch between the map
// and the backing store.  Debug mode will crash here in set_elements accessor.
literal.push(Math.E, Math.E);

// Corrupt the backing store!
KeyedStoreIC(literal);

// Release mode will crash here when trying to visit parts of E as pointers.
gc();
